@@ -1,4 +1,5 @@
 test_that("`query_category_members` returns data for a known request", {
+  skip_on_cran()
   physics_members <- wiki_action_request() %>% query_category_members("Physics", limit = 10) %>% next_batch()
   expect_equal(nrow(physics_members), 10)
 })
@@ -10,7 +11,8 @@ test_that("An appropriate error is thrown if `start` or `end` are used without `
     )
 })
 
-test_that("`build_query_tree` returns data for a known request", {
+test_that("`build_category_tree` returns data for a known request", {
+  skip_on_cran()
   tree <- build_category_tree("Category:Trees (data structures)")
   expect_named(tree, c("nodes", "edges"))
   expect_gt(nrow(tree$nodes), 1)
